@@ -2,12 +2,12 @@ package App::ForkProve;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.1.0';
+our $VERSION = '0.1.1';
 
 use App::Prove;
 use Getopt::Long ':config' => 'pass_through';
 
-use TAP::Parser::IteratorFactory;
+use App::ForkProve::SourceHandler;
 
 sub run {
     my($class, @args) = @_;
